import * as s3 from '@aws-cdk/aws-s3';
import * as cdk from '@aws-cdk/core';
import { CommonEfsAssetsProps } from './common-props';
/**
 * @stability stable
 */
export interface S3ArchiveFeederProps extends CommonEfsAssetsProps {
    /**
     * The S3 bucket containing the archive file.
     *
     * @stability stable
     */
    readonly bucket: s3.IBucket;
    /**
     * The path of the zip file to extract in the S3 bucket.
     *
     * @stability stable
     */
    readonly zipFilePath: string;
    /**
     * If this is set to true, then whenever a new object is uploaded to the specified path, an EFS sync will be triggered.
     *
     * Currently, this functionality depends on at least one CloudTrail Trail existing in your account that captures the S3
     * event.
     *
     * (optional, default: true)
     *
     * @stability stable
     */
    readonly syncOnUpdate?: boolean;
}
/**
 * @stability stable
 */
export declare class S3ArchiveSync extends cdk.Construct {
    /**
     * @stability stable
     */
    constructor(scope: cdk.Construct, id: string, props: S3ArchiveFeederProps);
}
